@@ -3,7 +3,7 @@ package DateTime::Locale::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.90';
+our $VERSION = '0.91';
 
 use Carp qw( carp );
 use DateTime::Locale;
@@ -485,12 +485,18 @@ DateTime::Locale::Base - Base class for individual locale objects
 
 =head1 VERSION
 
-version 0.90
+version 0.91
 
 =head1 SYNOPSIS
 
   use base 'DateTime::Locale::Base';
 
+=head1 DESCRIPTION
+
+B<This module is no longer used by the code in the distribution.> It is still
+included for the sake of any code out in the wild that may subclass this
+class. This class will be removed in a future release.
+
 =head1 DEFAULT FORMATS
 
 Each locale has a set of four default date and time formats.  They are
